{ config, lib, pkgs, modulesPath, inputs, ... }: let
  inherit (inputs) nixos-hardware;
in {
  imports =
    [ (modulesPath + "/installer/scan/not-detected.nix")
       nixos-hardware.nixosModules.apple-macbook-pro-8-1
    ];

  boot.initrd.availableKernelModules = [ "uhci_hcd" "ehci_pci" "ahci" "firewire_ohci" "usbhid" "usb_storage" "sd_mod" "sdhci_pci" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ "kvm-intel" "wl" ];
  boot.extraModulePackages = [ config.boot.kernelPackages.broadcom_sta ];

  fileSystems."/" =
    { device = "/dev/disk/by-uuid/33872d2c-3008-47ad-a7cf-fed7b259dfb0";
      fsType = "ext4";
    };

  boot.initrd.luks.devices."luks-732125b8-36af-43ea-b684-db71b4c20406".device = "/dev/disk/by-uuid/732125b8-36af-43ea-b684-db71b4c20406";

  fileSystems."/boot" =
    { device = "/dev/disk/by-uuid/3C84-DD6D";
      fsType = "vfat";
      options = [ "fmask=0077" "dmask=0077" ];
    };

  swapDevices = [ 
    {
      device = "/swapfile";
      size = 16*1024;
    }
  ];

  networking.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
